# Django-Start

---
Prepare a new Django project quickly and automatically and more wonderful things that save you time By django start

![Repo Stars](https://img.shields.io/github/stars/islam-kamel/django-start?style=social) ![Platform Support](https://img.shields.io/badge/platform-Windows%20%7C%20Linux%20%7C%20MacOs-green) ![Latest Version](https://img.shields.io/badge/Latest%20Version-1.0.4--beta-green) ![Downloads Count](https://img.shields.io/github/downloads/islam-kamel/django-start/total) ![GitHub (Pre-)Release Date](https://img.shields.io/github/release-date-pre/islam-kamel/django-start)

---

### Installation

````shell
pip install django-start-automate
````

````shell
django-start --help

Usage: django-start [OPTIONS] PROJECT_NAME APP_NAME

  Prepare a new Django project quickly and automatically and, more wonderful
  things that save you time By django start

Options:
  -n, --name <LAMBDA>    Custom Environment Name
  -v, --virtualenv TEXT  Install Environment Is Deprecated
  --help                 Show this message and exit.

````
**Success Install 🎊**

### Deprecated Options
- `-v, --virtualenv` Option is deprecated

### Build First Django Project
```shell
django-start project_name app_name
```

### Options
- `-n or -name` to set custom environment name

---
### django-version Command

```shell
Usage: django-version [OPTIONS]

Display current versio,
check new update and update django-start

Options:
  --update / --check-update TEXT
  --help         Show this message and exit.
```

### New
- `django-version`  Display django-start version
- `django-version --check-update`  Check New Update Available
- `django-version --update`  update django-start
---
### Welcome to contribute ❤
### [PyPi](https://pypi.org/project/django-start-automate/) 🧑‍💻
